summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jabberprotocol.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/protocols/jabber/jabberprotocol.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/protocols/jabber/jabberprotocol.h')
-rw-r--r--kopete/protocols/jabber/jabberprotocol.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/protocols/jabber/jabberprotocol.h b/kopete/protocols/jabber/jabberprotocol.h
index 6e647f74..0e79c357 100644
--- a/kopete/protocols/jabber/jabberprotocol.h
+++ b/kopete/protocols/jabber/jabberprotocol.h
@@ -39,11 +39,11 @@
namespace XMPP
{
class Resource;
- class Status;
+ class tqStatus;
}
class JabberContact;
-class dlgJabberStatus;
+class dlgJabbertqStatus;
class dlgJabberSendRaw;
class JabberCapabilitiesManager;
@@ -95,8 +95,8 @@ public:
const Kopete::ContactPropertyTmpl propWorkPhone;
const Kopete::ContactPropertyTmpl propWorkMobilePhone;
const Kopete::ContactPropertyTmpl propNickName;
- const Kopete::ContactPropertyTmpl propSubscriptionStatus;
- const Kopete::ContactPropertyTmpl propAuthorizationStatus;
+ const Kopete::ContactPropertyTmpl propSubscriptiontqStatus;
+ const Kopete::ContactPropertyTmpl propAuthorizationtqStatus;
const Kopete::ContactPropertyTmpl propAvailableResources;
const Kopete::ContactPropertyTmpl propVCardCacheTimeStamp;
const Kopete::ContactPropertyTmpl propPhoto;
@@ -141,9 +141,9 @@ public:
Kopete::OnlineStatus resourceToKOS ( const XMPP::Resource &resource );
/**
* Convert an online status to a XMPP::Status
*/
- XMPP::Status kosToStatus( const Kopete::OnlineStatus & status, const TQString& message=TQString() );
+ XMPP::tqStatus kosTotqStatus( const Kopete::OnlineStatus & status, const TQString& message=TQString() );
/**
* Return the Entity Capabilities(JEP-0115) manager instance.
@@ -141,9 +141,9 @@ public:
Kopete::OnlineStatus resourceToKOS ( const XMPP::Resource &resource );
/**
- * Convert an online status to a XMPP::Status
+ * Convert an online status to a XMPP::tqStatus
*/